@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 """
     pygments.styles.colorful
     ~~~~~~~~~~~~~~~~~~~~~~~~
 
     A colorful style, inspired by CodeRay.
 
-    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2023 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -19,8 +18,6 @@ class ColorfulStyle(Style):
     A colorful style, inspired by CodeRay.
     """
 
-    default_style = ""
-
     styles = {
         Whitespace:                "#bbbbbb",
 
